@@ -17,8 +17,6 @@ from localcosmos_server.forms import LocalizeableForm
 
 from localcosmos_server.template_content.utils import get_component_image_type
 
-from localcosmos_server.utils import get_public_schema_content_type_for_model
-
 import re
 
 User = get_user_model()
@@ -261,7 +259,7 @@ class TemplateContentFormFieldManager:
         else :
             if self.localized_template_content:
                 
-                ltc_content_type = get_public_schema_content_type_for_model(self.localized_template_content)
+                ltc_content_type = ContentType.objects.get_for_model(self.localized_template_content)
 
                 data_url_kwargs = {
                     'content_type_id' : ltc_content_type.id,
